Index: recipes/ios.py |
diff --git a/recipes/android.py b/recipes/ios.py |
similarity index 65% |
copy from recipes/android.py |
copy to recipes/ios.py |
index efc78a32abcc3410bc2297b92c4c020e639d7832..e7ee08b6d569a4efb867feaf4b4c09d163b78437 100644 |
--- a/recipes/android.py |
+++ b/recipes/ios.py |
@@ -1,4 +1,4 @@ |
-# Copyright (c) 2013 The Chromium Authors. All rights reserved. |
+# Copyright 2013 The Chromium Authors. All rights reserved. |
# Use of this source code is governed by a BSD-style license that can be |
# found in the LICENSE file. |
@@ -9,21 +9,21 @@ import recipe_util # pylint: disable=F0401 |
# This class doesn't need an __init__ method, so we disable the warning |
# pylint: disable=W0232 |
-class Android(recipe_util.Recipe): |
- """Basic Recipe alias for Android -> Chromium.""" |
+class IOS(recipe_util.Recipe): |
+ """Basic Recipe alias for iOS -> Chromium.""" |
@staticmethod |
def fetch_spec(props): |
return { |
'alias': { |
'recipe': 'chromium', |
- 'props': ['--target_os=android'], |
+ 'props': ['--target_os=ios', '--target_os_only=True'], |
}, |
} |
def main(argv=None): |
- return Android().handle_args(argv) |
+ return IOS().handle_args(argv) |
if __name__ == '__main__': |